#!/bin/bash
set -euo pipefail
# shellcheck disable=SC1091
source "${AGENT_PATH}/common.sh"
_check_required_env_vars "SERVER" "SERVICE" \
    "GITEA_RUNNER_DIRECTORY" "ACT_RUNNER_VERSION" \
    "GITEA_URL" "GITEA_TOKEN" "GITEA_RUNNER_NAME" "GITEA_RUNNER_LABELS" \
    "CONTAINER_NAME"

DOCKER_RUN_CMD="docker run -d \
                --restart unless-stopped \
                --name ${CONTAINER_NAME} \
                -e GITEA_INSTANCE_URL=${GITEA_URL} \
                -e GITEA_RUNNER_REGISTRATION_TOKEN=${GITEA_TOKEN} \
                -v /var/run/docker.sock:/var/run/docker.sock \
                -v ${GITEA_RUNNER_DIRECTORY}:/data \
                gitea/act_runner:nightly"


if ! _create_and_start_container "$DOCKER_RUN_CMD" "$CONTAINER_NAME"; then
    echo "${DOCKER_RUN_CMD}"
    _die "Failed to start container ${CONTAINER_NAME}"
fi

# Check if the container is running
if ! _is_container_running "$CONTAINER_NAME"; then
    _die "Container ${CONTAINER_NAME} is not running"
fi

echo "Container ${CONTAINER_NAME} started"
